;---------------------------------------------------------------------------
; sazanami-gothic installer for Battle for Wesnoth
; Written by naoki iimura (amatubu@gmail.com)

;  This installer will download sazanami font from SourceForge.jp and
;  install it to fonts folder of Battle for Wesnoth. Since the Windows
;  binary distribution of Battle for Wesnoth does not contains Asian fonts,
;  we need to install these fonts separately.
;  For more information about Wesnoth's Asian language support, see:
;    http://www.wesnoth.org/wiki/WesnothAsianLanguages

;---------------------------------------------------------------------------
;  This installer is free software; you can redistribute it and/or modify it
;  under the terms of version 2 of the GNU General Public License as
;  published by the Free Software Foundation.
;
;  This installer is distributed in the hope that it will be useful,
;  but WITHOUT ANY WARRANTY; without even the implied warranty of
;  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;  GNU General Public License for more details.
;
;  You should have received a copy of the GNU General Public License
;  along with POPFile; if not, write to the Free Software
;  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

;---------------------------------------------------------------------------
;  This script requires two NSIS plugins (Inetc and UnTGZ).
;  For more information about these plugins, see:

;  Inetc plug-in
;    http://nsis.sourceforge.net/Inetc_plug-in

;  UnTGZ plug-in (with bz2 support)
;    http://nsis.sourceforge.net/UnTGZ_plug-in

;---------------------------------------------------------------------------
;  This installer downloads fonts developed by the OpenSSL Project for use
;  in the OpenSSL Toolkit (http://www.openssl.org/)

;---------------------------------------------------------------------------
Name "Ȃ݃SVbN CXg[ for Battle for Wesnoth"

!include "MUI.nsh"

;---------------------------------------------------------------------------
;Configuration

  ;General
  OutFile "sazanami-setup.exe"

  ;Folder selection page
  ;InstallDir "$PROGRAMFILES\${MUI_PRODUCT}"
  InstallDir "$PROGRAMFILES\Battle for Wesnoth"

  ;Remember install folder
  ;InstallDirRegKey HKCU "Software\${MUI_PRODUCT}" ""
  InstallDirRegKey HKLM SOFTWARE\sazanami_for_wesnoth "InstallLocation"

;---------------------------------------------------------------------------
;URL

  !define C_URL_SAZANAMI "http://osdn.dl.sourceforge.jp/efont/10087/sazanami-20040629.tar.bz2"

;---------------------------------------------------------------------------
;Modern UI Configuration

  !insertmacro MUI_PAGE_WELCOME
  !insertmacro MUI_PAGE_LICENSE "README.txt"
  !insertmacro MUI_PAGE_COMPONENTS

  ; Find Battle for Wesnoth install directory
  !define MUI_PAGE_CUSTOMFUNCTION_PRE "CheckWesnothDir"

  !insertmacro MUI_PAGE_DIRECTORY
  !insertmacro MUI_PAGE_INSTFILES
  !insertmacro MUI_PAGE_FINISH

  !insertmacro MUI_UNPAGE_WELCOME
  !insertmacro MUI_UNPAGE_CONFIRM
  !insertmacro MUI_UNPAGE_INSTFILES
  !insertmacro MUI_UNPAGE_FINISH

;---------------------------------------------------------------------------
;Languages

  !insertmacro MUI_LANGUAGE "Japanese"

;---------------------------------------------------------------------------
;Language Strings

  ;Description
  LangString DESC_SecCopyUI ${LANG_JAPANESE} "Ȃ݃tHg (sazanami-gothic) CXg[܂B"

;---------------------------------------------------------------------------
;Installer Sections

Section "sazanami-gothic" SecCopyUI

  SectionIn RO

  ; size for sazanami-gothic.tar.bz2 and sazanami-gothic.ttf
  AddSize 15930

  ; Constants
  !define C_SAZANAMI_ARCHIVE "$INSTDIR\sazanami-gothic.tar.bz2"
  !define C_FONTS_DIR "$INSTDIR\fonts"
  !define C_SAZANAMI_FILE "sazanami-gothic.ttf"

  ; Check if Wesnoth has already installed or not
  IfFileExists "$INSTDIR" NoErrorMsg 0
    MessageBox MB_OK "$INSTDIR ɂ Battle for Wesnoth CXg[Ă܂BfāA܂ Battle for Wesnoth CXg[ĉB"
    Quit
  NoErrorMsg:

  SetOutPath "$INSTDIR"
  WriteUninstaller "sazanami-uninst.exe"

  ; If sazanami-font is already downloaded, skip downloading process
  IfFileExists "${C_SAZANAMI_ARCHIVE}" ExtractArchive 0

  ; Download sazanami-font
  DetailPrint "Ȃ݃tHg_E[hĂ܂..."
  inetc::get "${C_URL_SAZANAMI}" "${C_SAZANAMI_ARCHIVE}"
  DetailPrint ""

  ; Extract sazanami-gothic.ttf from archive into fonts folder
  ExtractArchive:
  DetailPrint "Ȃ݃tHgWJĂ܂..."
  untgz::extractFile -zbz2 -d "${C_FONTS_DIR}" "${C_SAZANAMI_ARCHIVE}" "${C_SAZANAMI_FILE}"
  
; TODO : Should we extract README of sazanami-fonts and the license of other fonts?
;  untgz::extractFile -zbz2 -d "${C_FONTS_DIR}" "${C_SAZANAMI_ARCHIVE}" "README"
;  untgz::extract -zbz2 "${C_SAZANAMI_ARCHIVE}"
  DetailPrint ""

  ; Write the installation path into the registry
  DetailPrint "WXg̓o^Ă܂..."
  WriteRegStr HKLM SOFTWARE\sazanami_for_wesnoth "Install_Dir" "$INSTDIR"

  ; Write the registry information related to uninstall
  WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\sazanami_for_wesnoth" "DisplayName" 'Ȃ݃tHg for Battle for Wesnoth'
  WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\sazanami_for_wesnoth" "UninstallString" '"$INSTDIR\sazanami-uninst.exe"'
  DetailPrint ""

SectionEnd

;---------------------------------------------------------------------------
;Descriptions

!insertmacro MUI_FUNCTION_DESCRIPTION_BEGIN
  !insertmacro MUI_DESCRIPTION_TEXT ${SecCopyUI} $(DESC_SecCopyUI)
!insertmacro MUI_FUNCTION_DESCRIPTION_END

;---------------------------------------------------------------------------
;Uninstaller Section

Section "Uninstall"

  ; remove registry keys
  DeleteRegKey HKLM SOFTWARE\sazanami_for_wesnoth
  DeleteRegKey HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\sazanami_for_wesnoth"

  ; Delete files
  Delete "${C_SAZANAMI_ARCHIVE}"
  Delete "${C_FONTS_DIR}\${C_SAZANAMI_FILE}"

  ; Resume backup files

  Delete "$INSTDIR\sazanami-uninst.exe"

SectionEnd
;---------------------------------------------------------------------------
; Find the Battle for Wesnoth install dir from Registry
Function CheckWesnothDir
  ; Windows version of Wesnoth installer creates following registry entry
  ReadRegStr $INSTDIR HKLM "SOFTWARE\Microsoft\Windows\CurrentVersion\Uninstall\Battle for Wesnoth_is1" "InstallLocation"
  StrCmp $INSTDIR "" UseDefault
  Goto exit

UseDefault:
  ; If registry does not exist, use default directory
  StrCpy $INSTDIR "$PROGRAMFILES\Battle for Wesnoth"

exit:
FunctionEnd
